@@ -3,7 +3,7 @@ package LCS::Tiny;
 use 5.006;
 use strict;
 use warnings;
-our $VERSION = '0.05';
+our $VERSION = '0.07';
 #use utf8;
 
 sub new {
@@ -97,7 +97,7 @@ LCS::Tiny - Tiny implementation of the
 
 =head1 SYNOPSIS
 
-  use Align::Sequence::BV;
+  use LCS::Tiny;
 
   $alg = LCS::Tiny->new;
   $lcs = $alg->LCS(\@a,\@b);
